/*
  Warnings:

  - You are about to drop the column `order` on the `Question` table. All the data in the column will be lost.
  - The primary key for the `Quiz` table will be changed. If it partially fails, the table could be left without primary key constraint.
  - You are about to drop the column `themeId` on the `Quiz` table. All the data in the column will be lost.
  - You are about to drop the `Theme` table. If the table is not empty, all the data it contains will be lost.

*/
-- DropForeignKey
ALTER TABLE `Question` DROP FOREIGN KEY `Question_quizId_fkey`;

-- DropForeignKey
ALTER TABLE `Quiz` DROP FOREIGN KEY `Quiz_themeId_fkey`;

-- AlterTable
ALTER TABLE `Question` DROP COLUMN `order`,
    MODIFY `quizId` CHAR(6) NOT NULL;

-- AlterTable
ALTER TABLE `Quiz` DROP PRIMARY KEY,
    DROP COLUMN `themeId`,
    ADD COLUMN `categoryId` INTEGER NULL,
    MODIFY `id` CHAR(6) NOT NULL,
    ADD PRIMARY KEY (`id`);

-- CreateTable
CREATE TABLE `Run` (
    `id` INTEGER NOT NULL AUTO_INCREMENT,
    `quizId` CHAR(6) NOT NULL,
    `startDate` DATETIME(3) NOT NULL DEFAULT CURRENT_TIMESTAMP(3),
    `lastChange` DATETIME(3) NOT NULL DEFAULT CURRENT_TIMESTAMP(3),
    `quizUserId` INTEGER NULL,

    PRIMARY KEY (`id`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `AnswerRun` (
    `runId` INTEGER NOT NULL,
    `answerId` INTEGER NOT NULL,
    `questionId` INTEGER NOT NULL,

    PRIMARY KEY (`runId`, `questionId`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `QuizUser` (
    `id` INTEGER NOT NULL AUTO_INCREMENT,
    `email` VARCHAR(191) NOT NULL,
    `username` VARCHAR(191) NOT NULL,
    `password` VARCHAR(191) NOT NULL,

    UNIQUE INDEX `QuizUser_email_key`(`email`),
    UNIQUE INDEX `QuizUser_username_key`(`username`),
    PRIMARY KEY (`id`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `Note` (
    `quizUserId` INTEGER NOT NULL,
    `quizId` CHAR(6) NOT NULL,
    `note` DOUBLE NOT NULL,

    PRIMARY KEY (`quizUserId`, `quizId`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- CreateTable
CREATE TABLE `Category` (
                            `id` INTEGER NOT NULL AUTO_INCREMENT,
                            `name` VARCHAR(191) NOT NULL,

                            UNIQUE INDEX `Category_name_key`(`name`),
                            PRIMARY KEY (`id`)
) DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- Copy data from `Theme` to `Category`
INSERT INTO `Category` (`id`, `name`) SELECT `id`, `name` FROM `Theme`;

-- DropForeignKey
ALTER TABLE `Question` DROP FOREIGN KEY `Question_themeId_fkey`;

-- Remove the column `themeId` from the `Question` table
ALTER TABLE `Question` DROP COLUMN `themeId`;

-- DropTable
DROP TABLE `Theme`;

-- AddForeignKey
ALTER TABLE `Quiz` ADD CONSTRAINT `Quiz_categoryId_fkey` FOREIGN KEY (`categoryId`) REFERENCES `Category`(`id`) ON DELETE SET NULL ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `Run` ADD CONSTRAINT `Run_quizId_fkey` FOREIGN KEY (`quizId`) REFERENCES `Quiz`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `Run` ADD CONSTRAINT `Run_quizUserId_fkey` FOREIGN KEY (`quizUserId`) REFERENCES `QuizUser`(`id`) ON DELETE SET NULL ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `AnswerRun` ADD CONSTRAINT `AnswerRun_runId_fkey` FOREIGN KEY (`runId`) REFERENCES `Run`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `AnswerRun` ADD CONSTRAINT `AnswerRun_answerId_fkey` FOREIGN KEY (`answerId`) REFERENCES `Answer`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `AnswerRun` ADD CONSTRAINT `AnswerRun_questionId_fkey` FOREIGN KEY (`questionId`) REFERENCES `Question`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `Note` ADD CONSTRAINT `Note_quizUserId_fkey` FOREIGN KEY (`quizUserId`) REFERENCES `QuizUser`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `Note` ADD CONSTRAINT `Note_quizId_fkey` FOREIGN KEY (`quizId`) REFERENCES `Quiz`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE `Question` ADD CONSTRAINT `Question_quizId_fkey` FOREIGN KEY (`quizId`) REFERENCES `Quiz`(`id`) ON DELETE RESTRICT ON UPDATE CASCADE;
