import {
  Controller,
  Get,
  Post,
  Body,
  Patch,
  Param,
  Delete,
  UseGuards,
  HttpException,
  HttpStatus,
} from '@nestjs/common';
import { QuestionService } from './question.service';
import { CreateQuestionDto } from './dto/create-question.dto';
import { UpdateQuestionDto } from './dto/update-question.dto';
import { AuthGuard } from '../../Auth/auth/auth.guard';
import { UserGuard } from '../user/user.guard';

@Controller('question')
export class QuestionController {
  constructor(private readonly questionService: QuestionService) {}

  @Post()
  async create(@Body() createQuestionDto: CreateQuestionDto) {
    try {
      return await this.questionService.create(createQuestionDto);
    } catch (error) {
      console.error('Error in create:', error);
      throw new HttpException(
        'Failed to create question',
        HttpStatus.BAD_REQUEST,
      );
    }
  }

  @UseGuards(AuthGuard, UserGuard)
  @Post('importQuestions')
  async importQuestions(
    @Body() body: { amount: number; category: number; difficulty: string },
  ) {
    try {
      const { amount, category, difficulty } = body;
      return await this.questionService.importQuestions(
        amount,
        category,
        difficulty,
      );
    } catch (error) {
      console.error('Error in importQuestions:', error);
      throw new HttpException(
        'Failed to import questions',
        HttpStatus.BAD_REQUEST,
      );
    }
  }

  @UseGuards(AuthGuard, UserGuard)
  @Patch(':quizId/:questionId')
  async updateQuestion(
    @Param('quizId') quizId: string,
    @Param('questionId') questionId: number,
    @Body() updateQuestionDto: UpdateQuestionDto,
  ) {
    try {
      return await this.questionService.updateQuestion(
        quizId,
        Number(questionId),
        updateQuestionDto,
      );
    } catch (error) {
      console.error('Error in updateQuestion:', error);
      throw new HttpException(
        'Failed to update question',
        HttpStatus.BAD_REQUEST,
      );
    }
  }

  @Get()
  async findAll() {
    try {
      return await this.questionService.findAll();
    } catch (error) {
      console.error('Error in findAll:', error);
      throw new HttpException(
        'Failed to retrieve questions',
        HttpStatus.BAD_REQUEST,
      );
    }
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    try {
      return await this.questionService.findOne(+id);
    } catch (error) {
      console.error('Error in findOne:', error);
      throw new HttpException(
        'Failed to retrieve question',
        HttpStatus.BAD_REQUEST,
      );
    }
  }

  @Delete(':id')
  async remove(@Param('id') id: string) {
    try {
      return await this.questionService.remove(+id);
    } catch (error) {
      console.error('Error in remove:', error);
      throw new HttpException(
        'Failed to remove question',
        HttpStatus.BAD_REQUEST,
      );
    }
  }
}
