import { Module } from '@nestjs/common';
import { QuestionService } from './question.service';
import { QuestionController } from './question.controller';
import { QuizService } from '../quiz/quiz.service';
import { QuizRepository } from '../quiz/store/quiz-repository';
import { QuizRepositoryOnDb } from '../quiz/store/quiz-repository-on-db';
import { RunService } from '../run/run.service';
import { HttpModule } from '@nestjs/axios';
import { PrismaModule } from '../../infra/prisma/prisma.module';
import { AnswerModule } from '../answer/answer.module';
import { RunRepository } from '../run/store/run-repository';
import { RunRepositoryOnDb } from '../run/store/run-repository-on-db';

@Module({
  imports: [HttpModule, PrismaModule, AnswerModule],
  controllers: [QuestionController],
  providers: [
    QuestionService,
    {
      provide: QuizService,
      useFactory: (quizRepository: QuizRepository, runService: RunService) =>
        new QuizService(quizRepository, runService),
      inject: [QuizRepository, RunService],
    },
    {
      provide: QuizRepository,
      useClass: QuizRepositoryOnDb,
    },
    {
      provide: RunRepository,
      useClass: RunRepositoryOnDb,
    },
    RunService,
  ],
  exports: [QuestionService],
})
export class QuestionModule {}
