import { Category, Difficulty, Question, Quiz } from '@prisma/client';
import { Answer } from '../../answer/entities/answer.entity';

type FullQuestion = Question & {
  answers?: Answer[] | null;
  category?: Category | null;
  difficulty?: Difficulty | null;
};

type FullQuiz = Quiz & {
  category?: Category | null;
  difficulty?: Difficulty | null;
  questions: FullQuestion[];
};

export abstract class QuizRepository {
  abstract save(quiz: Quiz): Promise<void>; //permet de sauvegarder un quiz
  abstract findById(id: string): Promise<FullQuiz | null>; //permet de retrouver un quiz par son id
  abstract findAll(): Promise<Quiz[]>;
  abstract getAnswers(
    id: string,
    questionId: number,
  ): Promise<Omit<Answer, 'isCorrect'>[]>;
  abstract updateQuestions(
    quizId: string,
    questionId: number,
    data: {
      text: string;
      type: string;
      answers: { text: string; isCorrect: boolean }[];
    },
  ): Promise<void>;
  abstract getPaginated(
    skip: number,
    take: number,
  ): Promise<{ quizzes: Quiz[]; total: number }>;
  abstract getStats(id: string): Promise<any>;
  abstract getPaginatedBySearch(
    skip: number,
    take: number,
    search: string,
  ): Promise<{ quizzes: Quiz[]; total: number }>;
  abstract getCategories(): Promise<Category[]>;
  abstract saveCategory(data: string): Promise<void>;
  abstract duplicateQuiz(id: string, newid: string): Promise<void>;
  abstract findByIdWithoutAnswers(id: string): Promise<FullQuiz | null>;
  abstract getInfo(quizId: string);
  abstract getUserCustomQuiz(userId: string): Promise<Quiz[]>;
}
