import { Injectable } from '@nestjs/common';
import { UpdateRunDto } from './dto/update-run.dto';
import { RunRepository } from './store/run-repository';
import { Run } from '@prisma/client';

@Injectable()
export class RunService {
  constructor(private readonly runRepository: RunRepository) {}

  create(
    runID: string,
    quizId: string,
    originalQuizId: string,
    userId: number,
    partyId?: string,
  ) {
    return this.runRepository.create(
      runID,
      quizId,
      originalQuizId,
      userId,
      partyId,
    );
  }

  getRunsByUser(userId: number) {
    return this.runRepository.getRunsByUser(userId);
  }

  getQuestions(id: string) {
    return this.runRepository.getQuestion(id);
  }

  findAll() {
    return this.runRepository.findAll();
  }

  findOne(id: string) {
    return this.runRepository.findOne(id);
  }

  findRemainingQuestions(id: string) {
    return this.runRepository.findRemainingQuestions(id);
  }

  update(id: string, updateRunDto: UpdateRunDto) {
    return `This action updates a #${id} run`;
  }

  incrementScore(id: string) {
    return this.runRepository.incrementScore(id);
  }

  incrementQuestionIndex(id: string) {
    return this.runRepository.incrementQuestionIndex(id);
  }

  getAnswers(id: string, questionID: number) {
    return this.runRepository.getAnswers(id, questionID);
  }

  remove(id: string) {
    return `This action removes a #${id} run`;
  }

  getScore(id: string) {
    return this.runRepository.getScore(id);
  }

  getRunByPartyAndHost(hostId: number) {
    return this.runRepository.getRunByHost(hostId);
  }

  async createWithoutLog(
    runID: string,
    quizId: string,
    originalQuizId: string,
    partyId?: string,
  ) {
    return this.runRepository.createWithoutLog(
      runID,
      quizId,
      originalQuizId,
      partyId,
    );
  }

  async info(id: string): Promise<Run | null> {
    return this.runRepository.info(id);
  }

  async generateUniqueId(): Promise<string> {
    const generateCode = () => {
      const characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
      let code = '';
      for (let i = 0; i < 6; i++) {
        code += characters.charAt(
          Math.floor(Math.random() * characters.length),
        );
      }
      return code;
    };

    let id;
    let isUnique = false;

    while (!isUnique) {
      id = generateCode();
      const existingQuiz = await this.runRepository.findOne(id);
      if (!existingQuiz) {
        isUnique = true;
      }
    }

    return id;
  }

  async getAnsweredQuestionId(id: string) {
    const questionId = await this.runRepository.findLastAnswered(id);

    return questionId;
  }
}
