import { Quiz, Run } from '@prisma/client';
import { FullQuestion } from 'src/utils/FullQuestion';

export abstract class RunRepository {
  abstract create(
    runID: string,
    quizId: string,
    originalQuizId: string,
    userId: number,
    roomId?: string,
  ): Promise<Run>;
  abstract findOne(id: string): Promise<Run | null>;
  abstract findAll(): Promise<Run[]>;
  abstract findRemainingQuestions(id: string): Promise<FullQuestion[]>;
  abstract incrementScore(id: string): Promise<void>;
  abstract incrementQuestionIndex(id: string): Promise<void>;
  abstract getAnswers(id: string, questionID: number): Promise<FullQuestion>;
  abstract getScore(id: string): Promise<number>;
  abstract createWithoutLog(
    runID: string,
    quizId: string,
    originalQuizId: string,
    roomId?: string,
  );
  abstract getRunByHost(hostId: number): Promise<Run & { quiz: Quiz }>;
  abstract getQuestion(id: string);
  abstract getRunsByUser(userId: number);
  abstract info(id: string): Promise<Run | null>;
  abstract findLastAnswered(runId: string): Promise<number>;
}
