import { Party, QuizUser } from '@prisma/client';
import { CreateUserDto } from '../dto/create-user.dto';
import { UpdateUserDto } from '../dto/update-user.dto';
import { User } from '../entities/user.entity';

export abstract class UserRepository {
  abstract create(user: CreateUserDto): Promise<User>;
  abstract update(user: UpdateUserDto): Promise<User>;
  abstract deleteById(id: number): Promise<void>;
  abstract findById(id: number): Promise<User>;
  abstract findByEmail(email: string): Promise<User>;
  abstract findByUsername(username: string): Promise<User>;
  abstract findByLogin(login: string): Promise<User>;
  abstract remove(id: number): Promise<User>;
  abstract findManyByPartyId(partyId: string): Promise<User[]>;
  abstract getStats(id: number): Promise<any>;
  abstract findAll(): Promise<User[]>;
  abstract findOneWithPartyInfos(
    id: number,
  ): Promise<QuizUser & { Party: Party }>;
}
