import {
  Controller,
  Get,
  Post,
  Body,
  Patch,
  Param,
  Delete,
  UseGuards,
  Req,
  HttpException,
} from '@nestjs/common';
import { UserService } from './user.service';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';
import { AuthGuard } from '../../Auth/auth/auth.guard';
import { UserGuard } from './user.guard';
import { UserRequest } from 'src/utils/UserRequest';

@Controller('user')
export class UserController {
  constructor(private readonly userService: UserService) {}

  @Post()
  create(@Body() createUserDto: CreateUserDto) {
    try {
      return this.userService.create(createUserDto);
    } catch (error) {
      throw new HttpException(error.message, error.status);
    }
  }

  @Get()
  findAll() {
    return this.userService.findAll();
  }

  @UseGuards(AuthGuard, UserGuard)
  @Get('me')
  async findOneByLogin(@Req() req: UserRequest) {
    // récupérer l'id de l'utilisateur depuis les cookies, puis l'envoie au service
    return await this.userService.findOne(req.userId);
  }

  @UseGuards(AuthGuard, UserGuard)
  @Get('stats/me')
  async getStats(@Req() req: UserRequest) {
    return await this.userService.getStats(req.userId);
  }

  @Get('stats/:id')
  getStatsById(@Param('id') id: string) {
    return this.userService.getStats(+id);
  }

  @UseGuards(AuthGuard)
  @Get(':id')
  findOne(@Param('id') id: string) {
    return this.userService.findOne(+id);
  }

  @Patch(':id')
  update(@Param('id') id: string, @Body() updateUserDto: UpdateUserDto) {
    return this.userService.update(updateUserDto);
  }

  @UseGuards(AuthGuard, UserGuard)
  @Delete(':id')
  remove(@Param('id') id: string) {
    return this.userService.remove(+id);
  }
}
