import { Injectable } from '@nestjs/common';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';
import { UserRepository } from './store/user-repository';

@Injectable()
export class UserService {
  constructor(private readonly userRepository: UserRepository) {}
  create(createUserDto: CreateUserDto) {
    return this.userRepository.create(createUserDto);
  }

  findAll() {
    return this.userRepository.findAll();
  }

  findOneByUsername(username: string) {
    return this.userRepository.findByUsername(username);
  }

  findOneByLogin(login: string) {
    return this.userRepository.findByLogin(login);
  }

  findOneWithPartyInfos(id: number) {
    return this.userRepository.findOneWithPartyInfos(id);
  }

  async findOne(id: number) {
    const userInfos = await this.userRepository.findById(id);
    const userStats = await this.userRepository.getStats(id);

    return { ...userInfos, stats: userStats };
  }

  async findManyByPartyId(partyId: string) {
    return this.userRepository.findManyByPartyId(partyId);
  }

  update(updateUserDto: UpdateUserDto) {
    return this.userRepository.update(updateUserDto);
  }

  getStats(id: number) {
    return this.userRepository.getStats(id);
  }

  remove(id: number) {
    return this.userRepository.remove(id);
  }
}
